Welcome to github-release-tool's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   cli
   installation
   modules
   contributing
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
